==> huaweicloudsdkvpn-3.1.110-py2.py3-none-any.whl: huaweicloudsdkvpn/v5/model/create_vpn_user_group_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateVpnUserGroupRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'user_group': 'CreateVpnUserGroupRequestBodyContent'
    }

    attribute_map = {
        'user_group': 'user_group'
    }

    def __init__(self, user_group=None):
        """CreateVpnUserGroupRequestBody

        The model defined in huaweicloud sdk

        :param user_group: 
        :type user_group: :class:`huaweicloudsdkvpn.v5.CreateVpnUserGroupRequestBodyContent`
        """
        
        

        self._user_group = None
        self.discriminator = None

        self.user_group = user_group

    @property
    def user_group(self):
        """Gets the user_group of this CreateVpnUserGroupRequestBody.

        :return: The user_group of this CreateVpnUserGroupRequestBody.
        :rtype: :class:`huaweicloudsdkvpn.v5.CreateVpnUserGroupRequestBodyContent`
        """
        return self._user_group

    @user_group.setter
    def user_group(self, user_group):
        """Sets the user_group of this CreateVpnUserGroupRequestBody.

        :param user_group: The user_group of this CreateVpnUserGroupRequestBody.
        :type user_group: :class:`huaweicloudsdkvpn.v5.CreateVpnUserGroupRequestBodyContent`
        """
        self._user_group = user_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVpnUserGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpn-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpn/v5/model/create_vpn_user_group_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateVpnUserGroupRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'user_group': 'CreateVpnUserGroupRequestBodyContent'
    }

    attribute_map = {
        'user_group': 'user_group'
    }

    def __init__(self, user_group=None):
        r"""CreateVpnUserGroupRequestBody

        The model defined in huaweicloud sdk

        :param user_group: 
        :type user_group: :class:`huaweicloudsdkvpn.v5.CreateVpnUserGroupRequestBodyContent`
        """
        
        

        self._user_group = None
        self.discriminator = None

        self.user_group = user_group

    @property
    def user_group(self):
        r"""Gets the user_group of this CreateVpnUserGroupRequestBody.

        :return: The user_group of this CreateVpnUserGroupRequestBody.
        :rtype: :class:`huaweicloudsdkvpn.v5.CreateVpnUserGroupRequestBodyContent`
        """
        return self._user_group

    @user_group.setter
    def user_group(self, user_group):
        r"""Sets the user_group of this CreateVpnUserGroupRequestBody.

        :param user_group: The user_group of this CreateVpnUserGroupRequestBody.
        :type user_group: :class:`huaweicloudsdkvpn.v5.CreateVpnUserGroupRequestBodyContent`
        """
        self._user_group = user_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVpnUserGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
